@@ -8,7 +8,7 @@ use base 'DBIx::Class::Schema::Loader::DBI';
 use Carp::Clan qw/^DBIx::Class/;
 use Class::C3;
 
-our $VERSION = '0.04002';
+our $VERSION = '0.04004';
 
 =head1 NAME
 
@@ -32,6 +32,16 @@ This module is considered experimental and not well tested yet.
 
 =cut
 
+sub _setup {
+    my $self = shift;
+
+    $self->next::method(@_);
+
+    my $dbh = $self->schema->storage->dbh;
+    $self->{db_schema} ||= $dbh->selectrow_array('SELECT USER FROM DUAL', {});
+}
+
+
 sub _table_columns {
     my ($self, $table) = @_;
 
